@@ -1,4 +1,4 @@
-/* $Id: miniupnpd.c,v 1.251 2021/08/21 08:27:53 nanard Exp $ */
+/* $Id: miniupnpd.c,v 1.253 2021/12/01 22:50:09 nanard Exp $ */
 /* vim: tabstop=4 shiftwidth=4 noexpandtab
  * MiniUPnP project
  * http://miniupnp.free.fr/ or https://miniupnp.tuxfamily.org/
@@ -1342,6 +1342,12 @@ init(int argc, char * * argv, struct runtime_vars * v)
 				break;
 #endif	/* ENABLE_MANUFACTURER_INFO_CONFIGURATION */
 #ifdef USE_NETFILTER
+			case UPNPTABLENAME:
+				set_rdr_name(RDR_TABLE_NAME, ary_options[i].value);
+				break;
+			case UPNPNATTABLENAME:
+				set_rdr_name(RDR_NAT_TABLE_NAME, ary_options[i].value);
+				break;
 			case UPNPFORWARDCHAIN:
 				set_rdr_name(RDR_FORWARD_CHAIN_NAME, ary_options[i].value);
 				break;
@@ -2528,22 +2534,32 @@ main(int argc, char * * argv)
 		{
 			syslog(LOG_INFO, "should send external iface address change notification(s)");
 			if(GETFLAG(PERFORMSTUNMASK))
-				update_ext_ip_addr_from_stun(0);
-			if (!use_ext_ip_addr)
+			{
+				if (update_ext_ip_addr_from_stun(0) != 0) {
+					/* if stun succeed it updates disable_port_forwarding;
+					 * if stun failed (non-zero return value) then port forwarding would not work, so disable it */
+					disable_port_forwarding = 1;
+				}
+			}
+			else if (!use_ext_ip_addr)
 			{
 				char if_addr[INET_ADDRSTRLEN];
 				struct in_addr addr;
-				if (getifaddr(ext_if_name, if_addr, INET_ADDRSTRLEN, &addr, NULL) == 0) {
+				if (getifaddr(ext_if_name, if_addr, INET_ADDRSTRLEN, &addr, NULL) < 0) {
+					syslog(LOG_WARNING, "Cannot get IP address for ext interface %s. Network is down", ext_if_name);
+					disable_port_forwarding = 1;
+				} else {
 					int reserved = addr_is_reserved(&addr);
-					if (disable_port_forwarding && !reserved) {
-						syslog(LOG_INFO, "Public IP address %s on ext interface %s: Port forwarding is enabled", if_addr, ext_if_name);
-					} else if (!disable_port_forwarding && reserved) {
+					if (!disable_port_forwarding && reserved) {
 						syslog(LOG_INFO, "Reserved / private IP address %s on ext interface %s: Port forwarding is impossible", if_addr, ext_if_name);
 						syslog(LOG_INFO, "You are probably behind NAT, enable option ext_perform_stun=yes to detect public IP address");
 						syslog(LOG_INFO, "Or use ext_ip= / -o option to declare public IP address");
 						syslog(LOG_INFO, "Public IP address is required by UPnP/PCP/PMP protocols and clients do not work without it");
+						disable_port_forwarding = 1;
+					} else if (disable_port_forwarding && !reserved) {
+						syslog(LOG_INFO, "Public IP address %s on ext interface %s: Port forwarding is enabled", if_addr, ext_if_name);
+						disable_port_forwarding = 0;
 					}
-					disable_port_forwarding = reserved;
 				}
 			}
 #ifdef ENABLE_NATPMP
