@@ -1,8 +1,8 @@
-/* $Id: upnpglobalvars.h,v 1.50 2020/09/28 21:48:48 nanard Exp $ */
+/* $Id: upnpglobalvars.h,v 1.52 2021/08/21 08:15:00 nanard Exp $ */
 /* vim: tabstop=4 shiftwidth=4 noexpandtab
  * MiniUPnP project
  * http://miniupnp.free.fr/ or https://miniupnp.tuxfamily.org/
- * (c) 2006-2020 Thomas Bernard
+ * (c) 2006-2021 Thomas Bernard
  * This software is subject to the conditions detailed
  * in the LICENCE file provided within the distribution */
 
@@ -29,6 +29,9 @@ extern uint16_t ext_stun_port;
 /* file to store all leases */
 #ifdef ENABLE_LEASEFILE
 extern const char * lease_file;
+#ifdef ENABLE_UPNPPINHOLE
+extern const char * lease_file6;
+#endif
 #endif
 
 /* forced ip address to use for this interface
@@ -171,4 +174,8 @@ extern unsigned int upnp_configid;
 extern char random_url[];
 #endif /* RANDOMIZE_URLS */
 
+#ifdef DYNAMIC_OS_VERSION
+extern char * os_version;
+#endif
+
 #endif /* UPNPGLOBALVARS_H_INCLUDED */
