@@ -1,8 +1,8 @@
-/* $Id: upnphttp.h,v 1.43 2020/12/20 17:44:59 nanard Exp $ */
+/* $Id: upnphttp.h,v 1.44 2021/08/21 08:11:09 nanard Exp $ */
 /* vim: tabstop=4 shiftwidth=4 noexpandtab
  * MiniUPnP project
  * http://miniupnp.free.fr/ or http://miniupnp.tuxfamily.org/
- * (c) 2006-2020 Thomas Bernard
+ * (c) 2006-2021 Thomas Bernard
  * This software is subject to the conditions detailed
  * in the LICENCE file provided within the distribution */
 
@@ -106,6 +106,9 @@ struct upnphttp {
 #define FLAG_ALLOW_POST			0x100
 #define FLAG_ALLOW_SUB_UNSUB	0x200
 
+/* If set, the User-Agent: contains "microsoft" */
+#define FLAG_MS_CLIENT	0x400
+
 #ifdef ENABLE_HTTPS
 int init_ssl(void);
 void free_ssl(void);
